@@ -1,6 +1,6 @@
 package WWW::Google::Places::SearchResult;
 
-$WWW::Google::Places::SearchResult::VERSION = '0.10';
+$WWW::Google::Places::SearchResult::VERSION = '0.11';
 
 use 5.006;
 use Moo;
@@ -20,12 +20,16 @@ WWW::Google::Places::SearchResult - Placeholder for Search Result for WWW::Googl
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-Google-Places>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-www-google-places at rt.cpan.org>,
